From: Byungchul Park <byungchul.p...@lge.com>

Usually, "msecs" notation means milli-seconds, and "usecs" notation
means micro-seconds. Since the unit used in the code is micro-seconds,
the notation should be replaced from msecs to usecs.

Signed-off-by: Byungchul Park <byungchul.p...@lge.com>
---
 kernel/trace/trace_functions_graph.c |   12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/kernel/trace/trace_functions_graph.c 
b/kernel/trace/trace_functions_graph.c
index f0a0c98..cb33f46 100644
--- a/kernel/trace/trace_functions_graph.c
+++ b/kernel/trace/trace_functions_graph.c
@@ -759,19 +759,19 @@ trace_print_graph_duration(unsigned long long duration, 
struct trace_seq *s)
 {
        unsigned long nsecs_rem = do_div(duration, 1000);
        /* log10(ULONG_MAX) + '\0' */
-       char msecs_str[21];
+       char usecs_str[21];
        char nsecs_str[5];
        int ret, len;
        int i;
 
-       sprintf(msecs_str, "%lu", (unsigned long) duration);
+       sprintf(usecs_str, "%lu", (unsigned long) duration);
 
        /* Print msecs */
-       ret = trace_seq_printf(s, "%s", msecs_str);
+       ret = trace_seq_printf(s, "%s", usecs_str);
        if (!ret)
                return TRACE_TYPE_PARTIAL_LINE;
 
-       len = strlen(msecs_str);
+       len = strlen(usecs_str);
 
        /* Print nsecs (we don't want to exceed 7 numbers) */
        if (len < 7) {
@@ -822,10 +822,10 @@ print_graph_duration(unsigned long long duration, struct 
trace_seq *s,
 
        /* Signal a overhead of time execution to the output */
        if (flags & TRACE_GRAPH_PRINT_OVERHEAD) {
                /* Duration exceeded 100 msecs */
                if (duration > 100000ULL)
                        ret = trace_seq_puts(s, "! ");
                /* Duration exceeded 10 msecs */
                else if (duration > 10000ULL)
                        ret = trace_seq_puts(s, "+ ");
        }
@@ -822,10 +822,10 @@ print_graph_duration(unsigned long long duration, struct 
        /* Signal a overhead of time execution to the output */
        if (flags & TRACE_GRAPH_PRINT_OVERHEAD) {
-               /* Duration exceeded 100 msecs */
+               /* Duration exceeded 100 usecs */
                if (duration > 100000ULL)
                        ret = trace_seq_puts(s, "! ");
@@ -822,10 +822,10 @@ print_graph_duration(unsigned long long duration, struct 
                if (duration > 100000ULL)
                        ret = trace_seq_puts(s, "! ");
-               /* Duration exceeded 10 msecs */
+               /* Duration exceeded 10 usecs */
                else if (duration > 10000ULL)
                        ret = trace_seq_puts(s, "+ ");
-- 
1.7.9.5

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to